"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertTemplateLiteralToLiteral = exports.convertTextToLiteral = exports.convertText = void 0;
const common_1 = require("./common");
/** Convert for Text */
function convertText(node, parent, ctx) {
    const text = Object.assign({ type: "SvelteText", value: node.data, parent }, ctx.getConvertLocation(node));
    extractTextTokens(node, ctx);
    return text;
}
exports.convertText = convertText;
/** Convert for Text to Literal */
function convertTextToLiteral(node, parent, ctx) {
    const text = Object.assign({ type: "SvelteLiteral", value: node.data, parent }, ctx.getConvertLocation(node));
    extractTextTokens(node, ctx);
    return text;
}
exports.convertTextToLiteral = convertTextToLiteral;
/** Convert for StyleDir's TemplateLiteral to Literal */
function convertTemplateLiteralToLiteral(node, parent, ctx) {
    const text = Object.assign({ type: "SvelteLiteral", value: node.quasis[0].value.raw, parent }, ctx.getConvertLocation(node));
    extractTextTokens(node, ctx);
    return text;
}
exports.convertTemplateLiteralToLiteral = convertTemplateLiteralToLiteral;
/** Extract tokens */
function extractTextTokens(node, ctx) {
    const loc = (0, common_1.getWithLoc)(node);
    let start = loc.start;
    let word = false;
    for (let index = loc.start; index < loc.end; index++) {
        if (word !== Boolean(ctx.code[index].trim())) {
            if (start < index) {
                ctx.addToken("HTMLText", { start, end: index });
            }
            word = !word;
            start = index;
        }
    }
    if (start < loc.end) {
        ctx.addToken("HTMLText", { start, end: loc.end });
    }
}
